Dataquery
---------

.. autosummary::
    :toctree: api/

    prismstudio.list_dataquery
    prismstudio.delete_dataquery
    prismstudio.load_dataquery
    prismstudio.save_dataquery
    prismstudio.rename_dataquery
    .. prismstudio.extract_dataquery